pub struct Formatter { /* private fields */ }Expand description
Main formatter struct
Implementations
Sourceimpl Formatter
impl Formatter
Sourcepub fn new(line_width: usize) -> Self
pub fn new(line_width: usize) -> Self
Create a new formatter with the given line width and wrap mode
Sourcepub fn with_wrap_mode(line_width: usize, wrap_mode: WrapMode) -> Self
pub fn with_wrap_mode(line_width: usize, wrap_mode: WrapMode) -> Self
Create a new formatter with the given line width and wrap mode
Sourcepub fn with_options(
line_width: usize,
wrap_mode: WrapMode,
ordered_list_mode: OrderedListMode,
) -> Self
pub fn with_options( line_width: usize, wrap_mode: WrapMode, ordered_list_mode: OrderedListMode, ) -> Self
Create a new formatter with all options